==> easy-core-0.50.2.tgz: package/src/config-service/app.config.ts <==
import { Injectable } from '@angular/core';
import { Http } from '@angular/http';
import { Observable, Subject } from 'rxjs/Rx';
import { Setting } from '../setting';


@Injectable()
export class AppConfig {

    private paths: Array<Setting> = [];
    private config: Array<Setting> = [];
    private env: Object = null;

    private subject = new Subject<boolean>();
    public initialized = this.subject.asObservable();

    constructor(private http: Http) { }

    public getPresentationConfigs() {
        return this.config.filter(x => x.key.toLowerCase().endsWith("config"));
    }

    public get(key: string) {
        let setting = this.config.filter(x => x.key.toLowerCase() == key.toLowerCase());

        return setting.length > 0 ? setting[0].value : null;
    }

    public getEnv(key: any) {
        return this.env[key];
    }

    public addNavigationItems(applicationName: string, paths: Array<any>) {
        for (let path of paths) {
            if (this.paths.filter(x => x.value.name == path.name).length == 0) {
                this.paths.push(new Setting(applicationName, { name: path.name, route: path.route }));
            }
        }
    }

    public fetchNavigationItems(applicationName: string) {
        return this.paths.filter(x => x.key === applicationName).map(x => new Setting(x.value.name, x.value.route));
    }

    public initialize(settings: Array<Setting>) {
        this.config = this.config.concat(settings);
    }

    public load() {
        return new Promise((resolve, reject) => {
            this.http.get('/config/env.json')
                .map(x => x.text() ? x.json() : {})
                .catch((error: any): any => {
                    console.log('Configuration file "env.json" could not be read');
                    resolve(true);
                    return Observable.throw(error.json().error || 'Server error');
                }).subscribe((envResponse) => {
                    this.env = envResponse;
                    let request: any = null;

                    switch (envResponse.env) {
                        case 'production': {
                            request = this.http.get('/config/config.' + envResponse.env + '.json');
                        } break;

                        case 'development': {
                            request = this.http.get('/config/config.' + envResponse.env + '.json');
                        } break;

                        case 'default': {
                            console.error('Environment file is not set or invalid');
                            resolve(true);
                        } break;
                    }

                    if (request) {
                        request
                            .map((res: any) => res.json())
                            .catch((error: any) => {
                                console.error('Error reading ' + envResponse.env + ' configuration file');
                                resolve(error);
                                return Observable.throw(error.json().error || 'Server error');
                            })
                            .subscribe((responseData: any) => {
                                this.config = [];
                                for (let setting of responseData.ApiConfigurations) {
                                    this.config.push(new Setting(setting.Name, setting.Value));
                                }
                                for (let setting of responseData.PresentationConfigurations) {
                                    this.config.push(new Setting(setting.Name, setting.Value));
                                }
                                this.subject.next(true);
                                resolve(true);
                            });
                    } else {
                        this.subject.next(false);
                        console.error('Env config file "env.json" is not valid');
                        resolve(true);
                    }
                });

        });
    }
}

==> easy-core-0.53.19.tgz: package/src/config-service/app.config.ts <==
import { Injectable } from '@angular/core';
import { Http } from '@angular/http';
import { Observable, Subject } from 'rxjs/Rx';
import { Setting } from '../setting';


@Injectable()
export class AppConfig {

    private paths: Array<Setting> = [];
    private config: Array<Setting> = [];
    private env: Object = null;

    private subject = new Subject<boolean>();
    public initialized = this.subject.asObservable();

    constructor(private http: Http) { }

    public getPresentationConfigs() {
        return this.config.filter(x => x.key.toLowerCase().endsWith("config"));
    }

    public get(key: string) {
        let setting = this.config.filter(x => x.key.toLowerCase() == key.toLowerCase());

        return setting.length > 0 ? setting[0].value : null;
    }

    public getEnv(key: any) {
        return this.env[key];
    }

    public addNavigationItems(applicationName: string, paths: Array<any>) {
        for (let path of paths) {
            if (this.paths.filter(x => x.value.name == path.name).length == 0) {
                this.paths.push(new Setting(applicationName, { name: path.name, route: path.route }));
            }
        }
    }

    public fetchNavigationItems(applicationName: string) {
        return this.paths.filter(x => x.key === applicationName).map(x => new Setting(x.value.name, x.value.route));
    }

    public initialize(settings: Array<Setting>, env: string) {
        this.config = this.config.concat(settings);
        this.env = env;
        this.subject.next(true);
    }
}
